@@ -1,12 +1,12 @@
 package Email::MIME::Kit;
 # ABSTRACT: build messages from templates
-$Email::MIME::Kit::VERSION = '3.000003';
+$Email::MIME::Kit::VERSION = '3.000004';
 require 5.008;
-use Moose;
+use Moose 0.65; # maybe_type
 use Moose::Util::TypeConstraints;
 
-use Email::MIME;
-use Email::MessageID;
+use Email::MIME 1.930; # header_raw
+use Email::MessageID 1.400; # for in_brackets method
 use String::RewritePrefix;
 
 #pod =head1 SYNOPSIS
@@ -286,7 +286,7 @@ Email::MIME::Kit - build messages from templates
 
 =head1 VERSION
 
-version 3.000003
+version 3.000004
 
 =head1 SYNOPSIS
 
